@@ -139,7 +139,7 @@ dbsource = Literal("DBSOURCE").suppress() + dedented
 dbln_type = Or(map(Literal, ["Project", "Trace Assembly Archive"]))
 dbln_type = dbln_type.setParseAction(lambda t: t[0].lower())
 dbln_list = Group(delimitedList(Word(alphanums + "_")))
-dblink = Literal("DBLINK") + Group(dbln_type + sup_colon + dbln_list)
+dblink = Literal("DBLINK").suppress() + Group(dbln_type + sup_colon + dbln_list)
 
 # PROJECT
 project = Literal("PROJECT").suppress() + normalized
@@ -285,7 +285,7 @@ def _k_dblink(data):
     for group in res:
         ret.append({
             "type": group[0],
-            "accessions": group[1]
+            "accessions": group[1].asList()
         })
     return ret
 
